# nest

The neural simulation tool.

Note: [Nest 2.16 does not support 32 bit hardware](https://github.com/nest/nest-simulator/issues/1031).

Note: it is not yet built with `libneurosim` support, so all models may not be
available in `PyNN`.

This documentation is also provided with each nest package variant as
`README.Fedora` (`nest`, `nest-mpich`, `nest-openmpi`):

The Fedora packages of the NEST simulator are built to cover various
configurations and installs their files in the standard locations:

- `nest:` NEST simulator without MPI support
- `python2-nest:` PyNEST for Python 2 without MPI support
- `python3-nest:` PyNEST for Python 3 without MPI support

- `nest-mpich:` NEST simulator build with MPICH support
- `python2-nest-mpich:` PyNEST for Python 2 with MPICH support
- `python3-nest-mpich:` PyNEST for Python 3 with MPICH support

- `nest-openmpi:` NEST simulator build with OpenMPI support
- `python2-nest-openmpi:` PyNEST for Python 2 with OpenMPI support
- `python3-nest-openmpi:` PyNEST for Python 3 with OpenMPI support

Usage
-----

The `nest_vars.sh` must be sourced to set up the environment correctly for NEST,
which makes use of a few environment variables:

- `NEST_INSTALL_DIR`
- `NEST_DATA_DIR`
- `NEST_MODULE_PATH`
- `NEST_PYTHON_PREFIX`
- `NEST_DOC_DIR`

The `nest_vars.sh` file is located in:

For MPICH builds:

`source /usr/lib64/mpich/bin/nest_vars_mpich.sh`

For OpenMPI builds:
`source /usr/lib64/openmpi/bin/nest_vars_openmpi.sh`


For non MPI builds:
`source /usr/bin/nest_vars.sh`

To use an MPI build of NEST, one must also load the appropriate module.
For MPICH builds:

`module load mpi/mpich-$arch # $arch is the architecture, for example x86_64`

For OpenMPI builds:

`module load mpi/openmpi-$arch # $arch is the architecture, for example x86_64`

It is generally easier to add these lines to the `~/.bashrc` file (for bash
users) so that these commands are automatically run on each login.

The binaries for each MPI build are suffixed to distinguish them from each
other:

For MPICH builds, they would be:

``````
nest_mpich
nest_vars_mpich.sh
nest_config_mpich
nest_serial_mpich
nest_indirect_mpich
sli_mpich
``````

For OpenMPI builds:
``````
nest_openmpi
nest_vars_openmpi.sh
nest_config_openmpi
nest_serial_openmpi
nest_indirect_openmpi
sli_openmpi
``````

Documentation
-------------
The generated documentation is provided in the nest-doc package, and is common
for all builds.

Official documentation can be found at http://nest-simulator.org/

For issues with this package, please contact the [NeuroFedora SIG](https://fedoraproject.org/wiki/SIGs/NeuroFedora#Communication_and_getting_help).
